@@ -6,10 +6,10 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-use strict; use warnings FATAL => 'all';
+use strict; use warnings;
 package POE::Filter::SpreadClient;
 BEGIN {
-  $POE::Filter::SpreadClient::VERSION = '1.000';
+  $POE::Filter::SpreadClient::VERSION = '1.001';
 }
 BEGIN {
   $POE::Filter::SpreadClient::AUTHORITY = 'cpan:APOCAL';
@@ -40,7 +40,7 @@ POE::Filter::SpreadClient - Implements the Spread filter for POE
 
 =head1 VERSION
 
-  This document describes v1.000 of POE::Filter::SpreadClient - released February 09, 2011 as part of POE-Component-SpreadClient.
+  This document describes v1.001 of POE::Filter::SpreadClient - released February 09, 2011 as part of POE-Component-SpreadClient.
 
 =head1 DESCRIPTION
 
